@@ -1,9 +1,13 @@
 # -*- coding: utf-8 -*-
-
+from __future__ import unicode_literals
 import re
 import difflib
 
 from django.db.models import fields
+try:
+    from django.db.models.fields.related import ForeignObject
+except ImportError:
+    from django.db.models.fields.related import RelatedField as ForeignObject
 from django.utils.html import escape
 
 
@@ -11,7 +15,7 @@ class BaseChange(object):
 
     def __repr__(self):
         value1, value2 = self.change
-        return u'Change object: %s - %s' % (value1, value2)
+        return 'Change object: %s - %s' % (value1, value2)
 
     def __init__(self, verbose_name, field, change):
         self.verbose_name = verbose_name
@@ -47,13 +51,17 @@ class ImageChange(BaseChange):
             {'left_image': left_image, 'right_image': right_image})
 
 
-def get_change(model1, model2, field):
+def get_change(model1, model2, field, resolve_foreignkeys=False):
     try:
         value1 = getattr(model1, "get_%s_display" % field.name)()
         value2 = getattr(model2, "get_%s_display" % field.name)()
     except AttributeError:
-        value1 = field.value_from_object(model1)
-        value2 = field.value_from_object(model2)
+        if isinstance(field, ForeignObject) and resolve_foreignkeys:
+            value1 = str(getattr(model1, field.name))
+            value2 = str(getattr(model2, field.name))
+        else:
+            value1 = field.value_from_object(model1)
+            value2 = field.value_from_object(model2)
 
     change = get_change_for_type(
         field.verbose_name,
@@ -64,17 +72,19 @@ def get_change(model1, model2, field):
     return change
 
 
-def get_changes_between_models(model1, model2, excludes=[]):
+def get_changes_between_models(model1, model2, excludes=[],
+                               resolve_foreignkeys=False):
     changes = {}
 
     for field in model1._meta.fields:
-        if not (isinstance(field, (fields.AutoField,))):
+        if not (isinstance(field, fields.AutoField)):
             if field.name in excludes:
                 continue
 
-            name = u"%s__%s" % (model1.__class__.__name__.lower(), field.name)
+            name = "%s__%s" % (model1.__class__.__name__.lower(), field.name)
 
-            changes[name] = get_change(model1, model2, field)
+            changes[name] = get_change(model1, model2, field,
+                                       resolve_foreignkeys)
 
     return changes
 
@@ -101,15 +111,15 @@ def html_to_list(html):
                          '(?:\w[\w-]*[ ]*)|(?:<[^<]*?>)|'
                          '(?:\s*[,\.\?]*)', re.UNICODE)
 
-    return [''.join(element) for element in filter(None,
-                                                   pattern.findall(html))]
+    return [''.join(element) for element in
+            [_f for _f in pattern.findall(html) if _f]]
 
 
 def get_change_for_type(verbose_name, change, field):
     if isinstance(field, fields.files.ImageField):
         change = ImageChange(
-            u"Current %(verbose_name)s / "
-            u"New %(verbose_name)s" % {'verbose_name': verbose_name},
+            "Current %(verbose_name)s / "
+            "New %(verbose_name)s" % {'verbose_name': verbose_name},
             field,
             change)
     else:
@@ -117,7 +127,7 @@ def get_change_for_type(verbose_name, change, field):
         change = TextChange(
             verbose_name,
             field,
-            (unicode(value1), unicode(value2)),
+            (str(value1), str(value2)),
         )
 
     return change
