@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 from django.db import models
 from django.conf import settings
 from django.core import serializers
@@ -40,7 +41,7 @@ class SerializedObjectField(models.TextField):
         value_set = [value]
         if value._meta.parents:
             value_set += [getattr(value, f.name)
-                          for f in value._meta.parents.values()
+                          for f in list(value._meta.parents.values())
                           if f is not None]
 
         return serializers.serialize(self.serialize_format, value_set)
@@ -51,7 +52,7 @@ class SerializedObjectField(models.TextField):
             value.encode(settings.DEFAULT_CHARSET),
             ignorenonexistent=True)
 
-        obj = obj_generator.next().object
+        obj = next(obj_generator).object
         for parent in obj_generator:
             for f in parent.object._meta.fields:
                 try:
