@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 from django.contrib.contenttypes.models import ContentType
 from django.utils.encoding import smart_unicode
 from django.utils.translation import ugettext as _
@@ -8,7 +9,7 @@ import moderation
 def _registered_content_types():
     "Return sorted content types for all registered models."
     content_types = []
-    registered = moderation.moderation._registered_models.keys()
+    registered = list(moderation.moderation._registered_models.keys())
     registered.sort(key=lambda obj: obj.__name__)
     for model in registered:
         content_types.append(ContentType.objects.get_for_model(model))
@@ -26,8 +27,8 @@ except ImportError:
         def __init__(self, *args, **kwargs):
             super(ContentTypeFilterSpec, self).__init__(*args, **kwargs)
             self.content_types = _registered_content_types()
-            self.lookup_choices = map(
-                lambda ct: (ct.id, ct.name.capitalize()), self.content_types)
+            self.lookup_choices = [(ct.id, ct.name.capitalize()) for ct in
+                                   self.content_types]
 
     get_filter = lambda f: getattr(f, 'content_type_filter', False)
     FilterSpec.filter_specs.insert(0, (get_filter, ContentTypeFilterSpec))
@@ -57,5 +58,5 @@ else:
                     'selected': smart_unicode(ct_type.id) == self.lookup_val,
                     'query_string': cl.get_query_string({
                         self.lookup_kwarg: ct_type.id}),
-                    'display': unicode(ct_type),
+                    'display': str(ct_type),
                 }
