@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 from moderation.register import RegistrationError
 
 
@@ -10,7 +11,7 @@ def automoderate(instance, user):
     try:
         status = instance.moderated_object.automoderate(user)
     except AttributeError:
-        msg = u"%s has been registered with Moderation." % instance.__class__
+        msg = "%s has been registered with Moderation." % instance.__class__
         raise RegistrationError(msg)
 
     return status
