@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+from django.utils.six import with_metaclass
 from moderation.models import ModeratedObject, MODERATION_STATUS_PENDING,\
     MODERATION_STATUS_APPROVED
 from django.core.exceptions import ObjectDoesNotExist
@@ -23,9 +25,7 @@ class ModerationManagerSingleton(type):
         return cls.instance
 
 
-class ModerationManager(object):
-    __metaclass__ = ModerationManagerSingleton
-
+class ModerationManager(with_metaclass(ModerationManagerSingleton, object)):
     def __init__(self, *args, **kwargs):
         """Initializes the moderation manager."""
         self._registered_models = {}
@@ -35,7 +35,7 @@ class ModerationManager(object):
     def register(self, model_class, moderator_class=None):
         """Registers model class with moderation"""
         if model_class in self._registered_models:
-            msg = u"%s has been registered with Moderation." % model_class
+            msg = "%s has been registered with Moderation." % model_class
             raise RegistrationError(msg)
         if not moderator_class:
             moderator_class = GenericModerator
