@@ -1,6 +1,7 @@
 """
 Test models used in django-moderations tests
 """
+from __future__ import unicode_literals
 from django.conf import settings
 from django.db import models
 from django.db.models.manager import Manager
@@ -16,6 +17,9 @@ class UserProfile(models.Model):
     def __unicode__(self):
         return "%s - %s" % (self.user, self.url)
 
+    def __str__(self):
+        return "%s - %s" % (self.user, self.url)
+
 
 class SuperUserProfile(UserProfile):
     super_power = models.TextField()
@@ -23,6 +27,9 @@ class SuperUserProfile(UserProfile):
     def __unicode__(self):
         return "%s - %s - %s" % (self.user, self.url, self.super_power)
 
+    def __str__(self):
+        return "%s - %s - %s" % (self.user, self.url, self.super_power)
+
 
 class ModelWithSlugField(models.Model):
     slug = models.SlugField(unique=True)
@@ -62,7 +69,10 @@ class ModelWithVisibilityField(models.Model):
     is_public = models.BooleanField(default=False)
 
     def __unicode__(self):
-        return u'%s - is public %s' % (self.test, self.is_public)
+        return '%s - is public %s' % (self.test, self.is_public)
+
+    def __str__(self):
+        return '%s - is public %s' % (self.test, self.is_public)
 
 
 class ModelWithWrongVisibilityField(models.Model):
@@ -70,7 +80,10 @@ class ModelWithWrongVisibilityField(models.Model):
     is_public = models.IntegerField()
 
     def __unicode__(self):
-        return u'%s - is public %s' % (self.test, self.is_public)
+        return '%s - is public %s' % (self.test, self.is_public)
+
+    def __str__(self):
+        return '%s - is public %s' % (self.test, self.is_public)
 
 
 class ModelWithImage(models.Model):
@@ -112,5 +125,8 @@ if VERSION[:2] >= (1, 5):
         def __unicode__(self):
             return "%s - %s" % (self.user, self.url)
 
+        def __str__(self):
+            return "%s - %s" % (self.user, self.url)
+
         def get_absolute_url(self):
             return '/test/'
