@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 from django.test.testcases import TestCase
 from django.contrib.auth.models import User
 from tests.models import UserProfile, \
@@ -33,9 +34,9 @@ class ModerationObjectsManagerTestCase(TestCase):
         ManagerClass = ModerationObjectsManager()(Manager)
 
         self.assertEqual(
-            unicode(ManagerClass.__bases__),
-            u"(<class 'moderation.managers.ModerationObjectsManager'>"
-            u", <class 'django.db.models.manager.Manager'>)")
+            str(ManagerClass.__bases__),
+            "(<class 'moderation.managers.ModerationObjectsManager'>"
+            ", <class 'django.db.models.manager.Manager'>)")
 
     def test_filter_moderated_objects_returns_empty_queryset(self):
         """Test filter_moderated_objects returns empty queryset
@@ -49,8 +50,8 @@ class ModerationObjectsManagerTestCase(TestCase):
         moderated_object = ModeratedObject(content_object=self.profile)
         moderated_object.save()
 
-        self.assertEqual(unicode(manager.filter_moderated_objects(query_set)),
-                         u"[]")
+        self.assertEqual(str(manager.filter_moderated_objects(query_set)),
+                         "[]")
 
     def test_filter_moderated_objects_returns_object(self):
         """Test if filter_moderated_objects return object when object 
@@ -62,8 +63,8 @@ class ModerationObjectsManagerTestCase(TestCase):
         self.profile.description = "New"
         self.profile.save()
 
-        self.assertEqual(unicode(UserProfile.objects.all()),
-                         u'[<UserProfile: moderator - http://www.google.com>]')
+        self.assertEqual(str(UserProfile.objects.all()),
+                         '[<UserProfile: moderator - http://www.google.com>]')
 
     def test_exclude_objs_by_visibility_col(self):
         ManagerClass = ModerationObjectsManager()(Manager)
@@ -78,8 +79,8 @@ class ModerationObjectsManagerTestCase(TestCase):
         query_set = manager.exclude_objs_by_visibility_col(query_set)
 
         self.assertEqual(
-            unicode(query_set),
-            u"[<ModelWithVisibilityField: test 2 - is public True>]")
+            str(query_set),
+            "[<ModelWithVisibilityField: test 2 - is public True>]")
 
 
 class ModeratedObjectManagerTestCase(TestCase):
@@ -111,6 +112,6 @@ class ModeratedObjectManagerTestCase(TestCase):
         moderated_obj2 = ModeratedObject.objects.get_for_instance(model2)
 
         self.assertEqual(repr(moderated_obj1),
-                         u"<ModeratedObject: ModelWithSlugField2 object>")
+                         "<ModeratedObject: ModelWithSlugField2 object>")
         self.assertEqual(repr(moderated_obj2),
-                         u'<ModeratedObject: user1 - http://www.yahoo.com>')
+                         '<ModeratedObject: user1 - http://www.yahoo.com>')
