@@ -1,4 +1,8 @@
-from django.conf.urls.defaults import patterns, include, handler500
+from __future__ import unicode_literals
+try:
+    from django.conf.urls.defaults import patterns, include, handler500
+except ImportError:
+    from django.conf.urls import patterns, include, handler500
 from django.conf import settings
 from django.contrib import admin
 from moderation.helpers import auto_discover
