@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 import sys
 try:
     from django.utils import unittest  # noqa
@@ -30,5 +31,5 @@ def setup_moderation(models=[]):
 def teardown_moderation():
     from moderation import moderation
 
-    for model in moderation._registered_models.keys():
+    for model in list(moderation._registered_models.keys()):
         moderation.unregister(model)
